==> igniteui-react-charts-18.0.0.tgz: package/esm5/lib/igr-plot-area-mouse-button-event-args.js <==
import { fromPoint, toPoint, ensureBool } from "igniteui-react-core";
/**
 * Provides data for IgxDataChartComponent mouse button related events.
*/
var IgrPlotAreaMouseButtonEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPlotAreaMouseButtonEventArgs() {
    }
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPlotAreaMouseButtonEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPlotAreaMouseButtonEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "chartPosition", {
        get: function () {
            return fromPoint(this.i.chartPosition);
        },
        set: function (v) {
            this.i.chartPosition = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "plotAreaPosition", {
        get: function () {
            return fromPoint(this.i.plotAreaPosition);
        },
        set: function (v) {
            this.i.plotAreaPosition = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "manipulationOccurred", {
        get: function () {
            return this.i.manipulationOccurred;
        },
        set: function (v) {
            this.i.manipulationOccurred = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "viewer", {
        /**
         * Gets the Chart associated with the current event.
        */
        get: function () {
            if (this.i.viewer == null) {
                return null;
            }
            return this.i.viewer.externalObject;
        },
        set: function (v) {
            v == null ? this.i.viewer = null : this.i.viewer = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPlotAreaMouseButtonEventArgs;
}());
export { IgrPlotAreaMouseButtonEventArgs };

==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/igr-plot-area-mouse-button-event-args.js <==
import { fromPoint, toPoint, ensureBool } from "igniteui-react-core";
/**
 * Provides data for IgxDataChartComponent mouse button related events.
*/
var IgrPlotAreaMouseButtonEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPlotAreaMouseButtonEventArgs() {
    }
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPlotAreaMouseButtonEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPlotAreaMouseButtonEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "chartPosition", {
        get: function () {
            return fromPoint(this.i.chartPosition);
        },
        set: function (v) {
            this.i.chartPosition = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "plotAreaPosition", {
        get: function () {
            return fromPoint(this.i.plotAreaPosition);
        },
        set: function (v) {
            this.i.plotAreaPosition = toPoint(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "manipulationOccurred", {
        get: function () {
            return this.i.manipulationOccurred;
        },
        set: function (v) {
            this.i.manipulationOccurred = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrPlotAreaMouseButtonEventArgs.prototype, "viewer", {
        /**
         * Gets the Chart associated with the current event.
        */
        get: function () {
            var r = this.i.viewer;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.viewer = null : this.i.viewer = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPlotAreaMouseButtonEventArgs;
}());
export { IgrPlotAreaMouseButtonEventArgs };
